@@ -28,10 +28,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KIdleTime>
 #include <KRandom>
 // Qt
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusReply>
-#include <QtDBus/QDBusServiceWatcher>
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include <QDBusServiceWatcher>
 
 namespace ScreenLocker
 {
@@ -83,7 +83,7 @@ uint Interface::GetSessionIdleTime()
 
 void Interface::Lock()
 {
-    if (!KAuthorized::authorizeKAction(QStringLiteral("lock_screen"))) {
+    if (!KAuthorized::authorizeAction(QStringLiteral("lock_screen"))) {
         return;
     }
     m_daemon->lock(calledFromDBus() ? EstablishLock::Immediate : EstablishLock::Delayed);
